## Dependency Module

The DI module uses [Guice](https://github.com/google/guice/wiki/) as a dependency injection container of the SDK. All
service interfaces that are bound to their implementations in one central location - the configure method.

### Service Binding

The ```SdkModule``` implements a guice Abstract Module and is configured with all necessary service binding. New
Implementations or Providers can be registered here.

```java

@Override
protected void configure(){

        bindConfigProperties();

        bind(CryptoService.class).to(JWECryptoService.class);
        bind(CertificateValidator.class).to(KeyValidator.class);
        bind(MetadataValidator.class).to(MetadataSubmissionValidator.class);
        bind(MetadataService.class).to(MetadataUploadService.class);

        bind(Sender.class).to(SubmissionSender.class);
        bind(Subscriber.class).to(SubmissionSubscriber.class);
        }
```

### Bootstrap and usage

In order to initialize the container the sdk-module needs to be loaded:

```java
private static final Injector injector=Guice.createInjector(new SdkModule());
```

The actual injection can be done in three ways via @Inject:

* Parameter Injection via @Injet on the field
* Constructor Injection via @Inject on the constructor
* Getting the Service directly from the DI Container, e.g. via ``injector.getService(Clazz.class)``

### Application Properties

The SDK can be externally configured via the config file ``/sdk.conf``. Those keys are loaded during guice
initialization and can be accessed via the ``@Named`` annotation. See [Guice](https://github.com/google/guice/wiki/)
for further information on the usage. 
